@@ -21,6 +21,7 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 #
+
 """dtool_lookup_api.core.LookupClient module."""
 
 
@@ -33,6 +34,10 @@ import aiohttp
 from .config import Config
 
 
+class LookupServerError(Exception):
+    pass
+
+
 async def authenticate(auth_url, username, password, verify_ssl=True):
     """Authenticate against token generator and return received token."""
     # async with aiohttp.ClientSession() as session:
@@ -91,12 +96,18 @@ class TokenBasedLookupClient:
     def header(self):
         return {'Authorization': f'Bearer {self.token}'}
 
+    def _check_json(self, json):
+        if isinstance(json, dict) and 'msg' in json:
+            raise LookupServerError(json['msg'])
+
     async def _get(self, route):
         """Return information from a specific route."""
         async with self.session.get(
                 f'{self.lookup_url}{route}',
                 headers=self.header, ssl=self.verify_ssl) as r:
-            return await r.json()
+            json = await r.json()
+            self._check_json(json)
+            return json
 
     async def _post(self, route, json, method='json'):
         async with self.session.post(
@@ -104,10 +115,12 @@ class TokenBasedLookupClient:
                 headers=self.header,
                 json=json,
                 ssl=self.verify_ssl) as r:
-            try:  # workaround for other non-json, non-method properties, better solutions welcme
-                return await getattr(r, method)()
+            try:  # workaround for other non-json, non-method properties, better solutions welcome
+                json = await getattr(r, method)()
             except TypeError:
-                return getattr(r, method)
+                json = getattr(r, method)
+            self._check_json(json)
+            return json
 
     async def summary(self):
         """Overall summary of datasets accessible to a user."""
@@ -120,7 +133,7 @@ class TokenBasedLookupClient:
     async def aggregate(self, aggregation):
         """Direct mongo aggregation, requires server-side direct mongo plugin."""
         if isinstance(aggregation, str):
-            query = json.loads(aggregation)
+            aggregation = json.loads(aggregation)
         return await self._post('/mongo/aggregate', dict(aggregation=aggregation))
 
     async def search(self, keyword):
@@ -175,12 +188,13 @@ class TokenBasedLookupClient:
         return await self._get(f'/user/info/{user}')
 
     async def list_users(self):
-        """Request a list of users. (Needs admin privilges.)"""
+        """Request a list of users. (Needs admin privileges.)"""
         return await self._get('/admin/user/list')
 
     async def register_base_uri(self, base_uri):
         """Register a base URI. (Needs admin privileges.)"""
-        return await self._post('/admin/base_uri/register', dict(base_uri=base_uri))
+        return await self._post('/admin/base_uri/register', dict(base_uri=base_uri),
+                                method='status') == 201
 
     async def list_base_uris(self):
         """List all registered base URIs. (Needs admin privileges.)"""
@@ -200,7 +214,8 @@ class TokenBasedLookupClient:
         return await self._post('/admin/permission/update_on_base_uri', dict(
             base_uri=base_uri,
             users_with_search_permissions=users_with_search_permissions,
-            users_with_register_permissions=users_with_register_permissions))
+            users_with_register_permissions=users_with_register_permissions),
+            method='status') == 201
 
 
 class CredentialsBasedLookupClient(TokenBasedLookupClient):
@@ -250,10 +265,6 @@ class ConfigurationBasedLookupClient(CredentialsBasedLookupClient):
             lookup_url = Config.lookup_url
         if auth_url is None:
             auth_url = Config.auth_url
-        if username is None:
-            username = Config.username
-        if password is None:
-            password = Config.password
         if verify_ssl is None:
             verify_ssl = Config.verify_ssl
 
@@ -284,6 +295,11 @@ class ConfigurationBasedLookupClient(CredentialsBasedLookupClient):
             logger.debug("Reusing provided token.")
             await TokenBasedLookupClient.connect(self)
         else:
+            # only look for username and password if really necessry
+            if self.username is None:
+                self.username = Config.username
+            if self.password is None:
+                self.password = Config.password
             logger.debug("Requesting new token.")
             await CredentialsBasedLookupClient.connect(self)
 
